#version 400

in vec3 position;
in vec3 normal;
in vec2 texcoord;

out vec3 eye_normal;
out vec3 eye_vertex;
out vec2 UV;

uniform mat4 model_matrix;
uniform mat4 view_matrix;
uniform mat4 projection_matrix;

void main()
{
	mat4 modelview_matrix = view_matrix * model_matrix;
	mat3 normal_matrix = mat3(transpose(inverse(modelview_matrix)));
	
	// The eye is sitting at the origin in eye space.  After
	// transforming a vertex into eye space with the modelview
	// matrix, the vector from the vertex to the eye is the
	// viewing direction.  We will pass along the transformed
	// vertex location to be interpolated across the triangle and
	// then used to compute viewing and lighting directions.
	eye_vertex = vec3(modelview_matrix * vec4(position, 1.0));

	// Need to transform the normal into eye space.
	eye_normal = normalize(normal_matrix * normal);

	UV = texcoord;

	// Always have to transform vertex positions so they end
	// up in the right place on the screen.
	gl_Position = projection_matrix * modelview_matrix * vec4(position, 1.0);
}

